

/*********************************************************************************************** 
*******			 				SAS Mixed Model Syntax 		     					    ********
************************************************************************************************/

/* PROC MIXED STATEMENT:
DATA=: 	File to use  default is last accessed
	NOCLPRINT: 	Do not print class variable values
	NOITPRINT: 	Do not print iteration history
	COVTEST: 	Print SEs and p-values for significance test of variance estimates 
	NAMELEN=:	# characters printed in fixed effects tables (default=20)
	METHOD=:	select REML or ML estimator - REML is default
Other options...
	IC:			Print other information criteria and associated df
	MAXITER=:	# iterations (default=50)
	EMPIRICAL:	adjust SEs for non-normality of residuals (sandwich estimator) --
         	    not available with Satterthwaite or KR DDFM (use BW instead) */
PROC MIXED DATA=work.datafile NOCLPRINT NOITPRINT COVTEST NAMELEN=100 METHOD=REML;


/* CLASS statement makes SAS dummy code categorical variables (highest value is reference)   	
	Also include ID variables and REPEATED variables on CLASS statement */
CLASS IDvar catvar1 catvar2 cattime;

		
/* MODEL STATEMENT:
Predict DV from time, catvar1, catvar2, contvar, 3 example interactions 
   	Don't need to construct interaction terms as variables a priori, use * between variables
	Options after the / ...
		NOINT:		Remove fixed intercept (is included by default)	
		SOLUTION: 	Print fixed effects solution (not included by default)
		DDFM=:		Change denominator degrees of freedom
					Choose from Satterthwaite, KR, BW 
	Other options...
		OUTP=:		Save predicted values from fixed+random effects to =dataset
		OUTPM=:		Save predicted values from fixed effects only to =dataset */
MODEL DV = time catvar1 catvar2 contvar catvar1*catvar2 time*catvar1 time*catvar2 
	/ SOLUTION DDFM=Satterthwaite;


/* RANDOM STATEMENT: Random Intercept must be listed if needed, also list any random slopes 
	Options after the / ...
		G GCORR:	Print covariance and correlation matrices for random effects
		V VCORR:	Print covariance and correlation matrices for total outcome
					V=1 VCORR=1 prints for 1st case (is default - can change if needed)
		TYPE=UN:	UN for unstructured to allow random effect covariances (VC=default) 
		SUBJECT:	ID variable to identify nesting per level
	Other options...
		SOLUTION: 	Print solution of random effects (the U's) - will take long time
		GROUP=:		=groupvar by which to get separate G matrices */	
RANDOM INTERCEPT time / G GCORR V VCORR TYPE=UN SUBJECT=IDvar;
		
	
/* REPEATED STATEMENT: is always there even if not listed
   	List variables repeated over (e.g., cattime) here and on CLASS statement
	Options after the / ...
		R RCORR:	Print covariance and correlation matrices for residuals
					R=1 RCORR=1 prints for 1st case (is default - can change if needed)
   		TYPE=VC:	VC for variance components (diagonal) by default 
					  many, many other types available, such as AR(1), TOEP(n) 
		SUBJECT:	ID variable to identify nesting per level (what is repeated over)
	Other options...
		GROUP=:		=groupvar by which to get separate R matrices
		LOCAL=:		EXP(predictor) for predictors of log of residual variance */
REPEATED cattime / R RCORR TYPE=VC SUBJECT=IDvar; 
	
/* Execute PROC MIXED */ 
RUN; 


/*****		OTHER OPTIONAL SAS PROC MIXED STATEMENTS 	******/

/* PARMS statement used to provide start values for variance components
   Must list as many () as there are variance components in the model
   List in order of appearance in CovParms table
	Options after the / ...
   		HOLD=: 	 	means fix those components (here, #3 is fixed to 1)
   		NOBOUND: 	allows variances to go negative (useful for troubleshooting) */	
PARMS (5) (3) (2) (1) / HOLD=3 NOBOUND;   
   

/* 	LSMEANS Generates means & tests for specified variables
	SLICE Tests effect of catvar1 at each level of catvar2 
   	if the time variable is at 1, uses Tukey Adjustment 
	DIFF=ALL requests all possible pairwise comparisons */
LSMEANS catvar1*catvar2 / SLICE=catvar2 AT time=1 ADJUST=TUKEY DIFF=ALL;	


/* 	ESTIMATE is used for specific hypothesis tests 
	"LABEL" is first, followed by effect being estimated.
   	Below we ask for group differences in main effect of catvar1 
   	and group differences in the linear slope of time */
ESTIMATE "L vs. H Catvar1 for Main Effect"   catvar1 -1  0  1 ;
ESTIMATE "M vs. H Catvar1 for Main Effect"   catvar1  0 -1  1 ;
ESTIMATE "L vs. M Catvar1 for Main Effect"   catvar1 -1  1  0 ;
ESTIMATE "L vs. H Catvar1 for Linear Slope"  time*catvar1 -1  0  1 ;
ESTIMATE "M vs. H Catvar1 for Linear Slope"  time*catvar1  0 -1  1 ;
ESTIMATE "L vs. M Catvar1 for Linear Slope"  time*catvar1 -1  1  0 ;

/* 	Below we ask for simple effects at the interacting variable=3 */
ESTIMATE "Simple Effect of X if Z=3"   xvar 1  xvar*zvar 3;	
ESTIMATE "Simple Effect of Z if X=3"   zvar 1  xvar*zvar 3;


/*	ODS OUTPUT is used to save output tables to SAS datasets 
	SolutionF=:		Save fixed effects to =dataset
	SolutionR=:		Save random effects to =dataset	
	CovParms=:		Save covariance parameters to =dataset
	FitStatistics=:	Save fit statistics to =dataset
	Estimates=:		Save requested estimates to =dataset */
ODS OUTPUT 	SolutionF=work.FixedEffects 
   	   		CovParms=work.CovarianceParameters 
   	   		FitStatistics=work.FitStats;
 	

 
